from argparse import RawDescriptionHelpFormatter
import os

class MetaVarlessFormatter(RawDescriptionHelpFormatter):
	def _format_action_invocation(self, action):
		if not action.option_strings:
			default = self._get_default_metavar_for_positional(action)
			metavar, = self._metavar_formatter(action, default)(1)
			return metavar
		else:
			parts = []

			if action.nargs == 0:
				parts.extend(action.option_strings)

			else:
				default = self._get_default_metavar_for_optional(action)
				args_string = self._format_args(action, default)
				for option_string in action.option_strings:
					parts.append(option_string)
				return '%s %s' % (', '.join(parts), args_string)

		return ', '.join(parts)

	def _get_default_metavar_for_optional(self, action):
		return action.dest.upper()

HAS_CURL = os.system(f"curl -SV > {os.devnull} 2>&1") != 0


import setuptools

setuptools.setup(
	name = "fastbooru",
	version= "0.1.1",
	description = "Because all other cli downloaders suck...",
	long_description = open("README.md", "r").read(),
	long_description_content_type = "text/markdown",
	author = "Cloud11665",
	author_email = 'Cloud11665@protonmail.com',
	url = "https://github.com/cloud11665/fastbooru",
	packages = setuptools.find_packages(),
	install_requires = setuptools.find_packages(),
	license= "gnu GPL-3.0",
	include_package_data = True,
	package_data = {"fastbooru": ["*.hy"]},
	entry_points = {
		"console_scripts": [
			"fastbooru = fastbooru:main"
		]
	},
	classifiers=[
		"Programming Language :: Python :: 3.7",
		"Programming Language :: Python :: 3.8",
		"Programming Language :: Python :: 3.9",
		"Operating System :: OS Independent"
	],
	python_requires = ">=3.7"
)